# MCRoute
Markov chain modelling of transportation networks.

This package enables the modelling of networks (transportation or otherwise) in
which movement through the network is represented by discrete state Markov
chains.

MCRoute extends the [NetworkX](https://networkx.org/documentation/stable/index.html)
module, requiring each node and edge to have an accompanying transition
probability matrix that can be used during network traversal calculations. The
package also incldues utility functions for constructing transition matrices
from data and theoretical distributions.

## Get Started

## Citing This Package
Please cite the following paper (currently under preparation):

**W. Klumpenhouwer** MCRoute: A Generalized Methodology for Modelling 
Transportation Networks with Markov Chains. (Under Preparation)